{
    'positive': {
        'required': False,
        'type': 'string'
    },
    'négative': {
        'required': False,
        'type': 'string'
    },
    'erreur': {
        'required': False,
        'type': 'string'
    }
}


{
    'nom': {
        'required': True,
        'type': 'string'
    },
    'entrée': {
        'required': True,
        'type': 'string'
    },
    'sortie': {
        'required': True,
        'type': 'string'
    },
    'rétroactions': {
        'required': False,
        'type': 'dict'
    }
}


{
    'ébauches': {
        'required': True,
        'type': 'dict',
    },
    'tests': {
        'required': True,
        'type': 'list',
        'schema': {
            'required': True,
            'type': 'dict',
            'schema': {
                'nom': {
                    'required': True,
                    'type': 'string'
                },
                'entrée': {
                    'required': True,
                    'type': ['string', 'integer']
                },
                'sortie': {
                    'required': True,
                    'type': ['string', 'integer']
                },
                'rétroactions': {
                    'required': False,
                    'type': 'dict',
                    'schema': {
                        'positive': {
                            'required': False,
                            'type': 'string'
                        },
                        'négative': {
                            'required': False,
                            'type': 'string'
                        },
                        'erreur': {
                            'required': False,
                            'type': 'string'
                        }
                    }
                }
            }
        }
    }
}



{
    'type': {
        'required': True,
        'type': 'string',
        'regex': '^(?i)(prog|sys|bd)$'
    },
    'titre': {
        'required': False,
        'type': 'string'
    },
    'description': {
        'required': False,
        'type': 'string'
    },
    'énoncé': {
        'required': False,
        'type': 'string'
    },
    'rétroactions': {
        'required': True,
        'type': 'dict',
        'schema': {
            'positive': {
                'required': False,
                'type': 'string'
            },
            'négative': {
                'required': False,
                'type': 'string'
            },
            'erreur': {
                'required': False,
                'type': 'string'
            }
        }
    }
}